# kipta


[![image](https://img.shields.io/pypi/v/kipta.svg)](https://pypi.python.org/pypi/kipta)
[![image](https://img.shields.io/conda/vn/conda-forge/kipta.svg)](https://anaconda.org/conda-forge/kipta)

[![image](https://pyup.io/repos/github/Dmutai/kipta/shield.svg)](https://pyup.io/repos/github/Dmutai/kipta)


**package testing**


-   Free software: MIT License
-   Documentation: https://Dmutai.github.io/kipta
    

## Features

-   TODO
